;; Generated package description from notmuch-indicator.el  -*- no-byte-compile: t -*-
(define-package "notmuch-indicator" "0.2.2" "Display mode line indicator with notmuch-count(1) output" '((emacs "27.1")) :commit "9a0bf7d85cc80e6c4c05bfd4d794a86926b3a8a9" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("notmuch-indicator Development" . "~protesilaos/notmuch-indicator@lists.sr.ht") :keywords '("convenience" "mail") :url "https://git.sr.ht/~protesilaos/notmuch-indicator")
